summaryrefslogtreecommitdiff
path: root/usr.bin/ssh/bufaux.h
diff options
context:
space:
mode:
Diffstat (limited to 'usr.bin/ssh/bufaux.h')
-rw-r--r--usr.bin/ssh/bufaux.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/usr.bin/ssh/bufaux.h b/usr.bin/ssh/bufaux.h
index 052cb14d630..06f3dfc5008 100644
--- a/usr.bin/ssh/bufaux.h
+++ b/usr.bin/ssh/bufaux.h
@@ -11,19 +11,19 @@ Created: Wed Mar 29 02:18:23 1995 ylo
*/
-/* RCSID("$Id: bufaux.h,v 1.1 1999/09/26 20:53:34 deraadt Exp $"); */
+/* RCSID("$Id: bufaux.h,v 1.2 1999/09/28 04:45:36 provos Exp $"); */
#ifndef BUFAUX_H
#define BUFAUX_H
#include "buffer.h"
/* Stores an MP_INT in the buffer with a 2-byte msb first bit count, followed
by (bits+7)/8 bytes of binary data, msb first. */
-void buffer_put_mp_int(Buffer *buffer, MP_INT *value);
+void buffer_put_bignum(Buffer *buffer, BIGNUM *value);
-/* Retrieves an MP_INT from the buffer. */
-int buffer_get_mp_int(Buffer *buffer, MP_INT *value);
+/* Retrieves an BIGNUM from the buffer. */
+int buffer_get_bignum(Buffer *buffer, BIGNUM *value);
/* Returns an integer from the buffer (4 bytes, msb first). */
unsigned int buffer_get_int(Buffer *buffer);
@@ -11,19 +11,19 @@ Created: Wed Mar 29 02:18:23 1995 ylo
#define BUFAUX_H
#include "buffer.h"
-/* Stores an MP_INT in the buffer with a 2-byte msb first bit count, followed
+/* Stores an BIGNUM in the buffer with a 2-byte msb first bit count, followed
by (bits+7)/8 bytes of binary data, msb first. */